@@ -1,4 +1,4 @@
-module.exports = {
+module.exports = { // eslint-disable-line no-undef
     "env": {
         "jest": true,
         "browser": true,
@@ -12,20 +12,19 @@ module.exports = {
     "settings": {
         "import/resolver": {
             "node": {
-                "moduleDirectory": '.transpile/node_modules'
+                "moduleDirectory": ".transpile/node_modules"
             },
-            [process.env.SRC_PATH + '/testing/eslint_import_resolver']: {}
+            [process.env.SRC_PATH + "/testing/eslint_import_resolver"]: {}
         }
     },
     "parser": "babel-eslint",
     "parserOptions": {
-      "sourceType": "module",
-      "allowImportExportEverywhere": true,
-      "ecmaFeatures": {
-        "globalReturn": false,
-      },
-      "ecmaVersion": 2018,
-      "sourceType": "module"
+        "sourceType": "module",
+        "allowImportExportEverywhere": true,
+        "ecmaFeatures": {
+            "globalReturn": false,
+        },
+        "ecmaVersion": 2018
     },
     "rules": {
         "accessor-pairs": "error",
@@ -81,12 +80,12 @@ module.exports = {
         "id-length": "off",
         "id-match": "error",
         "implicit-arrow-linebreak": "off",
-        "indent": "off",
+        "indent": ["error", 4],
         "indent-legacy": "off",
         "init-declarations": "off",
         "jsx-quotes": "error",
         "key-spacing": "off",
-        "keyword-spacing": ["warn", { "before": true, "after": true }],
+        "keyword-spacing": ["warn", {"before": true, "after": true}],
         "line-comment-position": "off",
         "linebreak-style": [
             "error",
@@ -206,7 +205,7 @@ module.exports = {
         "no-unmodified-loop-condition": "error",
         "no-unneeded-ternary": "off",
         "no-unused-expressions": "error",
-        "no-unused-vars": ["error", { "argsIgnorePattern": "^_" }],
+        "no-unused-vars": ["error", {"argsIgnorePattern": "^_"}],
         "no-use-before-define": "off",
         "no-useless-call": "error",
         "no-useless-catch": "off",
@@ -272,7 +271,7 @@ module.exports = {
         "space-before-blocks": "warn",
         "space-before-function-paren": ["warn", "never"],
         "space-in-parens": ["warn", "never"],
-        "space-infix-ops": "off",
+        "space-infix-ops": ["error", {"int32Hint": false}],
         "space-unary-ops": "off",
         "spaced-comment": "off",
         "strict": "error",
@@ -309,4 +308,4 @@ module.exports = {
         "transpile_VERSION":"readonly",
         "process": "readonly"
     }
-};
+}
