@@ -109,6 +109,8 @@ export class ModCollabDoc {
         // Adjust the document when reconnecting after offline and many changes
         // happening on server.
         if (this.mod.editor.docInfo.version < data.doc.v) {
+            this.receiving = true
+            this.mod.editor.docInfo.confirmedJson = JSON.parse(JSON.stringify(data.doc.contents))
             const confirmedState = EditorState.create({doc: this.mod.editor.docInfo.confirmedDoc})
             const unconfirmedTr = confirmedState.tr
             sendableSteps(this.mod.editor.view.state).steps.forEach(step => unconfirmedTr.step(step))
@@ -117,10 +119,15 @@ export class ModCollabDoc {
                 (step, index) => rollbackTr.step(step.invert(unconfirmedTr.docs[unconfirmedTr.docs.length - index - 1]))
             )
             // We reset to there being no local changes to send.
+            this.mod.editor.view.dispatch(receiveTransaction(
+                this.mod.editor.view.state,
+                unconfirmedTr.steps,
+                unconfirmedTr.steps.map(_step => this.mod.editor.client_id)
+            ))
             this.mod.editor.view.dispatch(receiveTransaction(
                 this.mod.editor.view.state,
                 rollbackTr.steps,
-                rollbackTr.steps.map(_step => this.mod.editor.client_id)
+                rollbackTr.steps.map(_step => 'remote')
             ))
             const toDoc = this.mod.editor.schema.nodeFromJSON({type:'doc', content:[
                 data.doc.contents
@@ -128,7 +135,6 @@ export class ModCollabDoc {
             const lostTr = recreateTransform(this.mod.editor.view.state.doc, toDoc)
             let tracked
             let localTr // local steps to be reapplied
-            const lostState = EditorState.create({doc: toDoc})
             if (
                 ['write', 'write-tracked'].includes(this.mod.editor.docInfo.access_rights) &&
                 (
@@ -142,7 +148,7 @@ export class ModCollabDoc {
                 // to the changes of this user and ask user to clean up.
                 localTr = trackedTransaction(
                     unconfirmedTr,
-                    lostState,
+                    confirmedState,
                     this.mod.editor.user,
                     false,
                     Date.now() - this.mod.editor.clientTimeAdjustment
@@ -151,7 +157,7 @@ export class ModCollabDoc {
                 tracked = false
                 localTr = unconfirmedTr
             }
-            const rebasedTr = lostState.tr.setMeta('remote', true)
+            const rebasedTr = EditorState.create({doc: toDoc}).tr.setMeta('remote', true)
             const maps = localTr.mapping.maps.slice().reverse().map(map => map.invert()).concat(lostTr.mapping)
             localTr.steps.forEach(
                 (step, index) => {
@@ -164,20 +170,20 @@ export class ModCollabDoc {
             const usedImages = [],
                 usedBibs = []
             const footnoteFind = (node, usedImages, usedBibs) => {
-                if (node.name==='citation') {
+                if (node.name === 'citation') {
                     node.attrs.references.forEach(ref => usedBibs.push(parseInt(ref.id)))
-                } else if (node.name==='figure' && node.attrs.image) {
+                } else if (node.name === 'figure' && node.attrs.image) {
                     usedImages.push(node.attrs.image)
                 } else if (node.content) {
                     node.content.forEach(subNode => footnoteFind(subNode, usedImages, usedBibs))
                 }
             }
             rebasedTr.doc.descendants(node => {
-                if (node.type.name==='citation') {
+                if (node.type.name === 'citation') {
                     node.attrs.references.forEach(ref => usedBibs.push(parseInt(ref.id)))
-                } else if (node.type.name==='figure' && node.attrs.image) {
+                } else if (node.type.name === 'figure' && node.attrs.image) {
                     usedImages.push(node.attrs.image)
-                } else if (node.type.name==='footnote' && node.attrs.footnote) {
+                } else if (node.type.name === 'footnote' && node.attrs.footnote) {
                     node.attrs.footnote.forEach(subNode => footnoteFind(subNode, usedImages, usedBibs))
                 }
             })
@@ -210,7 +216,8 @@ export class ModCollabDoc {
                 )
             }
             this.mod.editor.mod.footnotes.fnEditor.renderAllFootnotes()
-
+            this.receiving = false
+            this.sendToCollaborators()
         } else {
             // The server seems to have lost some data. We reset.
             this.loadDocument(data)
@@ -231,6 +238,7 @@ export class ModCollabDoc {
         this.mod.editor.docInfo = data.doc_info
         this.mod.editor.docInfo.version = data.doc.v
         this.mod.editor.docInfo.template = data.doc.template
+        this.mod.editor.docInfo.updated = new Date()
         this.mod.editor.mod.db.bibDB.setDB(data.doc.bibliography)
         this.mod.editor.mod.db.imageDB.setDB(data.doc.images)
         this.mod.editor.docInfo.confirmedJson = JSON.parse(JSON.stringify(data.doc.contents))
@@ -315,9 +323,9 @@ export class ModCollabDoc {
                     fnStepsToSend = sendableSteps(this.mod.editor.mod
                         .footnotes.fnEditor.view.state),
                     commentUpdates = this.mod.editor.mod.comments.store
-                    .unsentEvents(),
+                        .unsentEvents(),
                     bibliographyUpdates = this.mod.editor.mod.db.bibDB
-                    .unsentEvents(),
+                        .unsentEvents(),
                     imageUpdates = this.mod.editor.mod.db.imageDB.unsentEvents()
 
                 if (!stepsToSend &&
@@ -356,7 +364,7 @@ export class ModCollabDoc {
                     let newTitle = ""
                     this.mod.editor.view.state.doc.firstChild.firstChild.forEach(
                         child => {
-                            if (!child.marks.find(mark => mark.type.name==='deletion')) {
+                            if (!child.marks.find(mark => mark.type.name === 'deletion')) {
                                 newTitle += child.textContent
                             }
                         }
@@ -365,7 +373,7 @@ export class ModCollabDoc {
                     let oldTitle = ""
                     this.mod.editor.docInfo.confirmedDoc.firstChild.firstChild.forEach(
                         child => {
-                            if (!child.marks.find(mark => mark.type.name==='deletion')) {
+                            if (!child.marks.find(mark => mark.type.name === 'deletion')) {
                                 oldTitle += child.textContent
                             }
                         }
@@ -430,7 +438,7 @@ export class ModCollabDoc {
 
     receiveSelectionChange(data) {
         const participant = this.mod.participants.find(par => par.id === data
-                .id)
+            .id)
         let tr, fnTr
         if (!participant) {
             // participant is still unknown to us. Ignore
