@@ -266,52 +266,52 @@ export class Editor {
                         return // user navigated away.
                     }
                     switch (data.type) {
-                        case 'chat':
-                            this.mod.collab.chat.newMessage(data)
-                            break
-                        case 'connections':
-                            this.mod.collab.updateParticipantList(data.participant_list)
-                            break
-                        case 'styles':
-                            this.mod.documentTemplate.setStyles(data.styles)
-                            break
-                        case 'doc_data':
-                            this.mod.collab.doc.receiveDocument(data)
-                            break
-                        case 'confirm_version':
-                            this.mod.collab.doc.cancelCurrentlyCheckingVersion()
-                            if (data["v"] !== this.docInfo.version) {
-                                this.mod.collab.doc.checkVersion()
-                                return
-                            }
-                            this.mod.collab.doc.enableDiffSending()
-                            break
-                        case 'selection_change':
-                            this.mod.collab.doc.cancelCurrentlyCheckingVersion()
-                            if (data["v"] !== this.docInfo.version) {
-                                this.mod.collab.doc.checkVersion()
-                                return
-                            }
-                            this.mod.collab.doc.receiveSelectionChange(data)
-                            break
-                        case 'diff':
-                            if (data["cid"] === this.client_id) {
-                                // The diff origins from the local user.
-                                this.mod.collab.doc.confirmDiff(data["rid"])
-                                return
-                            }
-                            if (data["v"] !== this.docInfo.version) {
-                                this.mod.collab.doc.checkVersion()
-                                return
-                            }
-                            this.mod.collab.doc.receiveFromCollaborators(data)
-                            break
-                        case 'confirm_diff':
+                    case 'chat':
+                        this.mod.collab.chat.newMessage(data)
+                        break
+                    case 'connections':
+                        this.mod.collab.updateParticipantList(data.participant_list)
+                        break
+                    case 'styles':
+                        this.mod.documentTemplate.setStyles(data.styles)
+                        break
+                    case 'doc_data':
+                        this.mod.collab.doc.receiveDocument(data)
+                        break
+                    case 'confirm_version':
+                        this.mod.collab.doc.cancelCurrentlyCheckingVersion()
+                        if (data["v"] !== this.docInfo.version) {
+                            this.mod.collab.doc.checkVersion()
+                            return
+                        }
+                        this.mod.collab.doc.enableDiffSending()
+                        break
+                    case 'selection_change':
+                        this.mod.collab.doc.cancelCurrentlyCheckingVersion()
+                        if (data["v"] !== this.docInfo.version) {
+                            this.mod.collab.doc.checkVersion()
+                            return
+                        }
+                        this.mod.collab.doc.receiveSelectionChange(data)
+                        break
+                    case 'diff':
+                        if (data["cid"] === this.client_id) {
+                            // The diff origins from the local user.
                             this.mod.collab.doc.confirmDiff(data["rid"])
-                            break
-                        case 'reject_diff':
-                            this.mod.collab.doc.rejectDiff(data["rid"])
-                            break
+                            return
+                        }
+                        if (data["v"] !== this.docInfo.version) {
+                            this.mod.collab.doc.checkVersion()
+                            return
+                        }
+                        this.mod.collab.doc.receiveFromCollaborators(data)
+                        break
+                    case 'confirm_diff':
+                        this.mod.collab.doc.confirmDiff(data["rid"])
+                        break
+                    case 'reject_diff':
+                        this.mod.collab.doc.rejectDiff(data["rid"])
+                        break
                     }
                 }
 
@@ -455,18 +455,18 @@ export class Editor {
 
     // Collect all components of the current doc. Needed for saving and export
     // filters
-    getDoc(options={}) {
+    getDoc(options = {}) {
         const pmArticle = options.changes === 'acceptAllNoInsertions' ?
             acceptAllNoInsertions(this.docInfo.confirmedDoc).firstChild :
             this.docInfo.confirmedDoc.firstChild
-            let title = ""
-            pmArticle.firstChild.forEach(
-                child => {
-                    if (!child.marks.find(mark => mark.type.name==='deletion')) {
-                        title += child.textContent
-                    }
+        let title = ""
+        pmArticle.firstChild.forEach(
+            child => {
+                if (!child.marks.find(mark => mark.type.name === 'deletion')) {
+                    title += child.textContent
                 }
-            )
+            }
+        )
         return {
             contents: pmArticle.toJSON(),
             settings: getSettings(pmArticle),
@@ -527,7 +527,7 @@ export class Editor {
         view.dispatch(view.state.tr.setSelection(new TextSelection($pos, $pos)))
         view.focus()
         const distanceFromTop = view.coordsAtPos(pos).top - topMenuHeight
-        window.scrollBy(0, distanceFromTop)
+        window.scrollBy({left: 0, top: distanceFromTop, behavior:"smooth", block:"center"})
         return
     }
 
