@@ -29,6 +29,7 @@ export function getTimestamp(date) {
 
 export function styleEpubFootnotes(htmlEl) {
     // Converts RASH style footnotes into epub footnotes.
+    htmlEl.querySelector('section.fnlist').setAttribute('role', 'doc-endnotes')
     const footnotes = htmlEl.querySelectorAll('section.fnlist section[role=doc-footnote]')
     let footnoteCounter = 1
     footnotes.forEach(footnote => {
@@ -41,7 +42,7 @@ export function styleEpubFootnotes(htmlEl) {
             }
             newFootnote.firstChild.innerHTML = footnoteCounter + ' ' + newFootnote.firstChild.innerHTML
         } else {
-            newFootnote.innerHTML = '<p>'+footnoteCounter+'</p>'
+            newFootnote.innerHTML = '<p>' + footnoteCounter + '</p>'
         }
 
         footnote.parentNode.replaceChild(newFootnote, footnote)
@@ -63,7 +64,7 @@ export function styleEpubFootnotes(htmlEl) {
     return htmlEl
 }
 
-export function setLinks(htmlEl, docNum = 1) {
+export function setLinks(htmlEl, docNum = 0) {
     const contentItems = []
     let title
     let idCount = 0
@@ -112,12 +113,12 @@ export function orderLinks(contentItems) {
     return contentItems
 }
 
-export function addFigureLabels(htmlEl, language) {
+export function addFigureLabels(htmlEl, language, footnote = false) {
     // Due to lacking CSS support in ereaders, figure numbers need to be hardcoded.
     htmlEl.querySelectorAll('figcaption .figure-cat-figure').forEach(
         (el, index) => {
             const suffix = el.parentElement.innerText.trim().length ? ': ' : ''
-            el.innerHTML = `${FIG_CATS['figure'][language]} ${(index + 1)}${suffix}`
+            el.innerHTML = `${FIG_CATS['figure'][language]} ${(index + 1)}${footnote ? 'A' : ''}${suffix}`
             el.classList.remove('figure-cat-figure')
         }
     )
@@ -125,7 +126,7 @@ export function addFigureLabels(htmlEl, language) {
     htmlEl.querySelectorAll('figcaption .figure-cat-photo').forEach(
         (el, index) => {
             const suffix = el.parentElement.innerText.trim().length ? ': ' : ''
-            el.innerHTML = `${FIG_CATS['photo'][language]} ${(index + 1)}${suffix}`
+            el.innerHTML = `${FIG_CATS['photo'][language]} ${(index + 1)}${footnote ? 'A' : ''}${suffix}`
             el.classList.remove('figure-cat-photo')
         }
     )
@@ -133,10 +134,9 @@ export function addFigureLabels(htmlEl, language) {
     htmlEl.querySelectorAll('figcaption .figure-cat-table').forEach(
         (el, index) => {
             const suffix = el.parentElement.innerText.trim().length ? ': ' : ''
-            el.innerHTML = `${FIG_CATS['table'][language]} ${(index + 1)}${suffix}`
+            el.innerHTML = `${FIG_CATS['table'][language]} ${(index + 1)}${footnote ? 'A' : ''}${suffix}`
             el.classList.remove('figure-cat-table')
         }
     )
     return htmlEl
-
 }
