@@ -2,6 +2,7 @@ import {PAPER_SIZES} from "../../schema/const"
 import {HTMLExporter} from "../html"
 import {addAlert} from "../../common"
 import {removeHidden} from "../tools/doc_contents"
+import {printHTML} from "@vivliostyle/print"
 
 export class PrintExporter extends HTMLExporter {
 
@@ -10,10 +11,10 @@ export class PrintExporter extends HTMLExporter {
         this.styleSheets.push({contents:
             `a.fn {
                 -adapt-template: url(data:application/xml,${
-                    encodeURI(
-                        '<html xmlns="http://www.w3.org/1999/xhtml" xmlns:s="http://www.pyroxy.com/ns/shadow"><head><style>.footnote-content{float:footnote}</style></head><body><s:template id="footnote"><s:content/><s:include class="footnote-content"/></s:template></body></html>#footnote'
-                    )
-                });
+    encodeURI(
+        '<html xmlns="http://www.w3.org/1999/xhtml" xmlns:s="http://www.pyroxy.com/ns/shadow"><head><style>.footnote-content{float:footnote}</style></head><body><s:template id="footnote"><s:content/><s:include class="footnote-content"/></s:template></body></html>#footnote'
+    )
+});
                 text-decoration: none;
                 color: inherit;
                 vertical-align: baseline;
@@ -22,10 +23,22 @@ export class PrintExporter extends HTMLExporter {
                 top: -0.3em;
 
             }
+            body, section[role=doc-footnotes] {
+                counter-reset: figure-cat-0 figure-cat-1 figure-cat-2 footnote-counter footnote-marker-counter;
+            }
             section[role=doc-footnote] > *:first-child:before {
                 counter-increment: footnote-counter;
                 content: counter(footnote-counter) ". ";
             }
+            section[role=doc-footnote] .figure-cat-figure::after {
+                content: ' ' counter(figure-cat-0) 'A';
+            }
+            section[role=doc-footnote] .figure-cat-photo::after {
+                content: ' ' counter(figure-cat-1) 'A';
+            }
+            section[role=doc-footnote] .figure-cat-table::after {
+                content: ' ' counter(figure-cat-2) 'A';
+            }
             section.fnlist {
                 display: none;
             }
@@ -82,18 +95,18 @@ export class PrintExporter extends HTMLExporter {
         ).then(
             () => this.postProcess()
         ).then(
-            ({html, title}) => import("vivliostyle-print").then(
-                ({vivliostylePrint}) => vivliostylePrint(
+            ({html, title}) => {
+                return printHTML(
                     html,
                     {title}
                 )
-            )
+            }
         )
     }
 
     addDocStyle(doc) {
         // Override the default as we need to use the original URLs in print.
-        const docStyle = this.documentStyles.find(docStyle => docStyle.slug===doc.settings.documentstyle)
+        const docStyle = this.documentStyles.find(docStyle => docStyle.slug === doc.settings.documentstyle)
 
         if (!docStyle) {
             return
@@ -119,6 +132,10 @@ export class PrintExporter extends HTMLExporter {
         return Promise.resolve()
     }
 
+    addMathliveStylesheet() {
+        this.styleSheets.push({url: `${settings_STATIC_URL}css/libs/mathlive/mathlive.css?v=${transpile_VERSION}`})
+    }
+
     getFootnoteAnchor(counter) {
         const footnoteAnchor = super.getFootnoteAnchor(counter)
         // Add the counter directly into the footnote.
