@@ -33,6 +33,9 @@ class WebSocket(BaseWebSocketHandler):
             self.access_denied()
             return
         self.document_id = int(self.args[0])
+        logger.debug(
+            f"Action:Document socket opened by user. "
+            f"URL:{self.endpoint} User:{self.user.id} ParticipantID:{self.id}")
 
     def confirm_diff(self, rid):
         response = {
@@ -53,13 +56,18 @@ class WebSocket(BaseWebSocketHandler):
             doc_db.id in WebSocket.sessions and
             len(WebSocket.sessions[doc_db.id]['participants']) > 0
         ):
-            logger.debug("Serving already opened file")
+            logger.debug(
+                f"Action:Serving already opened document. "
+                f"URL:{self.endpoint} User:{self.user.id} "
+                f" ParticipantID:{self.id}")
             self.doc = WebSocket.sessions[doc_db.id]
             self.id = max(self.doc['participants']) + 1
             self.doc['participants'][self.id] = self
-            logger.debug("id when opened %s" % self.id)
         else:
-            logger.debug("Opening file")
+            logger.debug(
+                f"Action:Opening document from DB. "
+                f"URL:{self.endpoint} User:{self.user.id} "
+                f"ParticipantID:{self.id}")
             self.id = 0
             self.doc = {
                 'db': doc_db,
@@ -79,6 +87,9 @@ class WebSocket(BaseWebSocketHandler):
                 }
             }
             WebSocket.sessions[doc_db.id] = self.doc
+        logger.debug(
+            f"Action:Participant ID Assigned. URL:{self.endpoint} "
+            f"User:{self.user.id} ParticipantID:{self.id}")
         self.send_message({
             'type': 'subscribed'
         })
@@ -198,7 +209,10 @@ class WebSocket(BaseWebSocketHandler):
             self.subscribe_doc(connection_count)
             return
         if self.user_info.document_id not in WebSocket.sessions:
-            logger.debug('receiving message for closed document')
+            logger.debug(
+                f"Action:Receiving message for closed document. "
+                f"URL:{self.endpoint} User:{self.user.id} "
+                f"ParticipantID:{self.id}")
             return
         if message["type"] == 'get_document':
             self.send_document()
@@ -348,17 +362,18 @@ class WebSocket(BaseWebSocketHandler):
     def handle_diff(self, message):
         pv = message["v"]
         dv = self.doc['version']
-        logger.debug("PV: %d, DV: %d" % (pv, dv))
+        logger.debug(
+            f"Action:Handling Diff. URL:{self.endpoint} User:{self.user.id} "
+            f"ParticipantID:{self.id} Client version:{pv} "
+            f"Server version:{dv} Message:{message}")
         if (
             self.user_info.access_rights in COMMENT_ONLY and
             not self.only_comments(message)
         ):
             logger.error(
-                (
-                    'received non-comment diff from comment-only '
-                    'collaborator. Discarding.'
-                )
-            )
+                f"Action:Received non-comment diff from comment-only "
+                f"collaborator.Discarding URL:{self.endpoint} "
+                f"User:{self.user.id} ParticipantID:{self.id}")
             return
         if pv == dv:
             self.doc["last_diffs"].append(message)
@@ -374,9 +389,18 @@ class WebSocket(BaseWebSocketHandler):
                        True
                     )
                 except (JsonPatchConflict, JsonPointerException):
-                    logger.exception("Cannot apply json diff.")
-                    logger.error(json_encode(message))
-                    logger.error(json_encode(self.doc['contents']))
+                    logger.exception(
+                        f"Action:Cannot apply json diff. "
+                        f"URL:{self.endpoint} User:{self.user.id} "
+                        f"ParticipantID:{self.id}")
+                    logger.error(
+                        f"Action:Patch Exception URL:{self.endpoint} "
+                        f"User:{self.user.id} ParticipantID:{self.id} "
+                        f"Message:{json_encode(message)}")
+                    logger.error(
+                        f"Action:Patch Exception URL:{self.endpoint} "
+                        f"User:{self.user.id} ParticipantID:{self.id} "
+                        f"Document:{json_encode(self.doc['contents'])}")
                     self.unfixable()
                 # The json diff is only needed by the python backend which does
                 # not understand the steps. It can therefore be removed before
@@ -402,25 +426,37 @@ class WebSocket(BaseWebSocketHandler):
         elif pv < dv:
             if pv + len(self.doc["last_diffs"]) >= dv:
                 # We have enough last_diffs stored to fix it.
-                logger.debug("can fix it")
                 number_diffs = pv - dv
+                logger.debug(
+                    f"Action:Resending document diffs. URL:{self.endpoint} "
+                    f"User:{self.user.id} ParticipantID:{self.id} "
+                    f"number of messages to be resent:{number_diffs}")
                 messages = self.doc["last_diffs"][number_diffs:]
                 for message in messages:
                     new_message = message.copy()
                     new_message["server_fix"] = True
                     self.send_message(new_message)
             else:
-                logger.debug('unfixable')
+                logger.debug(
+                    f"Action:User is on a very old version of the document. "
+                    f"URL:{self.endpoint} User:{self.user.id} "
+                    f"ParticipantID:{self.id}")
                 # Client has a version that is too old to be fixed
                 self.unfixable()
         else:
             # Client has a higher version than server. Something is fishy!
-            logger.debug('unfixable')
+            logger.debug(
+                f"Action:User has higher document version than server.Fishy! "
+                f"URL:{self.endpoint} User:{self.user.id} "
+                f"ParticipantID:{self.id}")
 
     def check_version(self, message):
         pv = message["v"]
         dv = self.doc['version']
-        logger.debug("PV: %d, DV: %d" % (pv, dv))
+        logger.debug(
+            f"Action:Checking version of document. URL:{self.endpoint} "
+            f"User:{self.user.id} ParticipantID:{self.id} "
+            f"Client document version:{pv} Server document version:{dv}")
         if pv == dv:
             response = {
                 "type": "confirm_version",
@@ -429,8 +465,11 @@ class WebSocket(BaseWebSocketHandler):
             self.send_message(response)
             return
         elif pv + len(self.doc["last_diffs"]) >= dv:
-            logger.debug("can fix it")
             number_diffs = pv - dv
+            logger.debug(
+                f"Action:Resending document diffs. URL:{self.endpoint} "
+                f"User:{self.user.id} ParticipantID:{self.id}"
+                f"number of messages to be resent:{number_diffs}")
             messages = self.doc["last_diffs"][number_diffs:]
             for message in messages:
                 new_message = message.copy()
@@ -438,7 +477,10 @@ class WebSocket(BaseWebSocketHandler):
                 self.send_message(new_message)
             return
         else:
-            logger.debug('unfixable')
+            logger.debug(
+                f"Action:User is on a very old version of the document. "
+                f"URL:{self.endpoint} User:{self.user.id} "
+                f"ParticipantID:{self.id}")
             # Client has a version that is too old
             self.unfixable()
             return
@@ -450,7 +492,9 @@ class WebSocket(BaseWebSocketHandler):
         return self.user_info.access_rights in CAN_COMMUNICATE
 
     def on_close(self):
-        logger.debug('Websocket closing')
+        logger.debug(
+            f"Action:Closing websocket. URL:{self.endpoint} "
+            f"User:{self.user.id} ParticipantID:{self.id}")
         if (
             hasattr(self, 'user_info') and
             hasattr(self.user_info, 'document_id') and
@@ -464,7 +508,9 @@ class WebSocket(BaseWebSocketHandler):
             if len(self.doc['participants']) == 0:
                 WebSocket.save_document(self.user_info.document_id)
                 del WebSocket.sessions[self.user_info.document_id]
-                logger.debug("noone left")
+                logger.debug(
+                    f"Action:No participants for the document. "
+                    f"URL:{self.endpoint} User:{self.user.id}")
             else:
                 WebSocket.send_participant_list(self.user_info.document_id)
 
@@ -493,9 +539,8 @@ class WebSocket(BaseWebSocketHandler):
     @classmethod
     def send_updates(cls, message, document_id, sender_id=None, user_id=None):
         logger.debug(
-            "Sending message to %d waiters",
-            len(cls.sessions[document_id]['participants'])
-        )
+            f"Action:Sending message to waiters. DocumentID:{document_id} "
+            f"waiters:{len(cls.sessions[document_id]['participants'])}")
         for waiter in list(cls.sessions[document_id]['participants'].values()):
             if waiter.id != sender_id:
                 access_rights = waiter.user_info.access_rights
@@ -546,8 +591,9 @@ class WebSocket(BaseWebSocketHandler):
         doc_db.last_diffs = json_encode(doc['last_diffs'])
         doc_db.comments = json_encode(doc['comments'])
         doc_db.bibliography = json_encode(doc['bibliography'])
-        logger.debug('saving document # %d' % doc_db.id)
-        logger.debug('version %d' % doc_db.version)
+        logger.debug(
+            f"Action:Saving document to DB. DocumentID:{doc_db.id} "
+            f"Doc version:{doc_db.version}")
         try:
             # this try block is to avoid a db exception
             # in case the doc has been deleted from the db
